@@ -345,13 +345,13 @@ use_default_clicked_callback (GtkWidget *button, gpointer user_data)
 }
 
 static GtkWidget *
-button_new_with_mnemonic (const gchar *stockid, const gchar *str)
+button_new_with_mnemonic (const gchar *icon_name, const gchar *str)
 {
 	GtkWidget *image;
 	GtkWidget *button;
 	
 	button = gtk_button_new_with_mnemonic (str);
-	image = gtk_image_new_from_stock (stockid, GTK_ICON_SIZE_BUTTON);
+	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_BUTTON);
 	
 	gtk_button_set_image (GTK_BUTTON (button), image);
 
@@ -367,7 +367,7 @@ add_buttons (NemoColumnChooser *chooser)
 	box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
 	gtk_widget_show (box);
 	
-	chooser->details->move_up_button = button_new_with_mnemonic (GTK_STOCK_GO_UP,
+	chooser->details->move_up_button = button_new_with_mnemonic ("go-up-symbolic",
 								     _("Move _Up"));
 	g_signal_connect (chooser->details->move_up_button, 
 			  "clicked",  G_CALLBACK (move_up_clicked_callback),
@@ -377,7 +377,7 @@ add_buttons (NemoColumnChooser *chooser)
 	gtk_box_pack_start (GTK_BOX (box), chooser->details->move_up_button,
 			    FALSE, FALSE, 0);
 
-	chooser->details->move_down_button = button_new_with_mnemonic (GTK_STOCK_GO_DOWN,
+	chooser->details->move_down_button = button_new_with_mnemonic ("go-down-symbolic",
 								       _("Move Dow_n"));
 	g_signal_connect (chooser->details->move_down_button, 
 			  "clicked",  G_CALLBACK (move_down_clicked_callback),
