@@ -61,6 +61,8 @@ static char *used_metadata_names[] = {
   (char *)NEMO_METADATA_KEY_SHOW_THUMBNAILS,
   (char *)NEMO_METADATA_KEY_DESKTOP_GRID_ADJUST,
   (char *)NEMO_METADATA_KEY_PINNED,
+  (char *)NEMO_METADATA_KEY_FAVORITE,
+  (char *)NEMO_METADATA_KEY_FAVORITE_AVAILABLE,
   NULL
 };
 
