@@ -29,7 +29,6 @@
 #include <eel/eel-glib-extensions.h>
 #include "nemo-progress-info.h"
 #include "nemo-progress-info-manager.h"
-#include "nemo-icon-info.h"
 
 enum {
   CHANGED,
@@ -380,7 +379,13 @@ idle_callback (gpointer data)
     info->queue_at_idle = FALSE;
 	
 	G_UNLOCK (progress_info);
-	
+
+    if (queue_at_idle) {
+        g_signal_emit (info,
+                   signals[QUEUED],
+                   0);
+    }
+
 	if (start_at_idle) {
 		g_signal_emit (info,
 			       signals[STARTED],
@@ -404,12 +409,6 @@ idle_callback (gpointer data)
 			       signals[FINISHED],
 			       0);
 	}
-	
-    if (queue_at_idle) {
-        g_signal_emit (info,
-                   signals[QUEUED],
-                   0);
-    }
 
 	g_object_unref (info);
 	
@@ -637,7 +636,7 @@ nemo_progress_info_set_progress (NemoProgressInfo *info,
 	G_LOCK (progress_info);
 	
 	if (info->activity_mode || /* emit on switch from activity mode */
-	    fabs (current_percent - info->progress) > 0.005 /* Emit on change of 0.5 percent */
+	    fabs (current_percent - info->progress) > 0
 	    ) {
 		info->activity_mode = FALSE;
 		info->progress = current_percent;
