@@ -116,8 +116,8 @@ nemo_icon_view_grid_container_get_icon_images (NemoIconContainer *container,
         if (s < size)
             size = s;
 
-        bad_ratio = (int)nemo_icon_get_emblem_size_for_icon_size (size) * scale > w ||
-                    (int)nemo_icon_get_emblem_size_for_icon_size (size) * scale > h;
+        bad_ratio = (int)nemo_icon_get_emblem_size_for_icon_size (size) * scale > (int)(w * 0.75) ||
+                    (int)nemo_icon_get_emblem_size_for_icon_size (size) * scale > (int)(h * 0.75);
 
         if (bad_ratio)
             goto skip_emblem; /* Would prefer to not use goto, but
@@ -174,24 +174,6 @@ nemo_icon_view_grid_container_get_icon_description (NemoIconContainer *container
 	return g_strdup (description);
 }
 
-static void
-nemo_icon_view_grid_container_prioritize_thumbnailing (NemoIconContainer *container,
-						      NemoIconData      *data)
-{
-	NemoFile *file;
-	char *uri;
-
-	file = (NemoFile *) data;
-
-	g_assert (NEMO_IS_FILE (file));
-
-	if (nemo_file_is_thumbnailing (file)) {
-		uri = nemo_file_get_uri (file);
-		nemo_thumbnail_prioritize (uri);
-		g_free (uri);
-	}
-}
-
 static void
 update_auto_strv_as_quarks (GSettings   *settings,
 			    const gchar *key,
@@ -1679,7 +1661,6 @@ nemo_icon_view_grid_container_class_init (NemoIconViewGridContainerClass *klass)
 	ic_class->get_icon_text = nemo_icon_view_grid_container_get_icon_text;
 	ic_class->get_icon_images = nemo_icon_view_grid_container_get_icon_images;
 	ic_class->get_icon_description = nemo_icon_view_grid_container_get_icon_description;
-	ic_class->prioritize_thumbnailing = nemo_icon_view_grid_container_prioritize_thumbnailing;
     ic_class->get_max_layout_lines_for_pango = nemo_icon_view_grid_container_get_max_layout_lines_for_pango;
     ic_class->get_max_layout_lines = nemo_icon_view_grid_container_get_max_layout_lines;
     ic_class->get_additional_text_line_count = nemo_icon_view_grid_container_get_additional_text_line_count;
