@@ -76,12 +76,24 @@ enum {
 
 static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
+enum {
+    CHECK_ADMIN_LOCATION,
+    LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
 G_DEFINE_TYPE (NemoToolbar, nemo_toolbar, GTK_TYPE_BOX);
 
 static void
 nemo_toolbar_update_root_state (NemoToolbar *self)
 {
-    if ((nemo_user_is_root () && !nemo_treating_root_as_normal()) &&
+    gboolean is_admin_uri;
+
+    g_signal_emit (self, signals[CHECK_ADMIN_LOCATION], 0, &is_admin_uri);
+
+    if ((is_admin_uri ||
+         (nemo_user_is_root () && !nemo_treating_root_as_normal())) &&
          g_settings_get_boolean (nemo_preferences, NEMO_PREFERENCES_SHOW_ROOT_WARNING)) {
         if (self->priv->show_root_bar != TRUE) {
             self->priv->show_root_bar = TRUE;
@@ -225,6 +237,7 @@ toolbar_create_toolbutton (NemoToolbar *self,
     gtk_activatable_set_related_action (GTK_ACTIVATABLE (button), action);
     gtk_button_set_label (GTK_BUTTON (button), NULL);
     gtk_widget_set_tooltip_text (button, gtk_action_get_tooltip (action));
+    gtk_widget_set_can_focus (button, FALSE);
     gtk_style_context_add_class (gtk_widget_get_style_context (button), GTK_STYLE_CLASS_FLAT);
 
     return button;
@@ -391,6 +404,9 @@ nemo_toolbar_constructed (GObject *obj)
     g_signal_connect_swapped (nemo_preferences,
                   "changed::" NEMO_PREFERENCES_SHOW_IMAGE_FILE_THUMBNAILS,
                   G_CALLBACK (toolbar_update_appearance), self);
+    g_signal_connect_swapped (nemo_preferences,
+                  "changed::" NEMO_PREFERENCES_SHOW_LOCATION_ENTRY,
+                  G_CALLBACK (toolbar_update_appearance), self);
 
 	toolbar_update_appearance (self);
 }
@@ -492,6 +508,13 @@ nemo_toolbar_class_init (NemoToolbarClass *klass)
 				      TRUE,
 				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	
+    signals[CHECK_ADMIN_LOCATION] =
+        g_signal_new ("check-admin-location",
+                      G_TYPE_FROM_CLASS (klass),
+                      G_SIGNAL_RUN_LAST,
+                      0, NULL, NULL, NULL,
+                      G_TYPE_BOOLEAN, 0);
+
 	g_type_class_add_private (klass, sizeof (NemoToolbarClass));
 	g_object_class_install_properties (oclass, NUM_PROPERTIES, properties);
 }
@@ -546,3 +569,9 @@ nemo_toolbar_set_show_location_entry (NemoToolbar *self,
 		g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_SHOW_LOCATION_ENTRY]);
 	}
 }
+
+void
+nemo_toolbar_update_for_location (NemoToolbar *self)
+{
+    toolbar_update_appearance (self);
+}
\ No newline at end of file
