@@ -303,19 +303,6 @@ action_preferences_callback (GtkAction *action,
 	nemo_file_management_properties_dialog_show (window, NULL);
 }
 
-static void
-action_plugins_callback (GtkAction *action,
-                         gpointer user_data)
-{
-    GtkWindow *window;
-
-    if (!NEMO_IS_DESKTOP_WINDOW (user_data)) {
-        window = GTK_WINDOW (user_data);
-
-        nemo_file_management_properties_dialog_show (window, "plugins");
-    }
-}
-
 static void
 action_about_nemo_callback (GtkAction *action,
 				gpointer user_data)
@@ -1320,10 +1307,26 @@ action_new_folder_callback (GtkAction *action,
 static void
 open_in_terminal_other (const gchar *path)
 {
-    gchar *argv[2];
-    argv[0] = g_settings_get_string (gnome_terminal_preferences, GNOME_DESKTOP_TERMINAL_EXEC);
-    argv[1] = NULL;
-    g_spawn_async(path, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL);
+    gchar *gsetting_terminal;
+    gchar **token;
+    gchar **argv;
+    gint i;
+
+    gsetting_terminal = g_settings_get_string (gnome_terminal_preferences,
+                                               GNOME_DESKTOP_TERMINAL_EXEC);
+
+    token = g_strsplit (gsetting_terminal, " ", 0);
+    argv = g_new (gchar *, g_strv_length (token) + 1);
+    for (i = 0; token[i] != NULL; i++) {
+        argv[i] = token[i];
+    }
+    argv[i] = NULL;
+
+    g_spawn_async (path, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL);
+
+    g_free (gsetting_terminal);
+    g_strfreev (token);
+    g_free (argv);
 }
 
 
@@ -1374,10 +1377,6 @@ static const GtkActionEntry main_entries[] = {
                                  N_("Prefere_nces"),
                                  NULL, N_("Edit Nemo preferences"),
                                  G_CALLBACK (action_preferences_callback) },
-                               { NEMO_ACTION_PLUGIN_MANAGER, NULL,
-                                 N_("Plugins"),
-                                 "<alt>p", N_("Manage extensions, actions and scripts"),
-                                 G_CALLBACK (action_plugins_callback) },
 #ifdef TEXT_CHANGE_UNDO
   /* name, stock id, label */  { "Undo", NULL, N_("_Undo"),
                                  "<control>Z", N_("Undo the last text change"),
