@@ -70,13 +70,9 @@ struct NemoWindowSlot {
 	GtkWidget *floating_bar;
     GtkWidget *cache_bar;
     GtkWidget *no_search_results_box;
-    GtkWidget *drop_bar;
-    GtkWidget *drop_bar_icon;
-    GtkWidget *drop_bar_label;
 
 	guint set_status_timeout_id;
 	guint loading_timeout_id;
-    guint drop_bar_hide_timeout_id;
 
 	NemoView *content_view;
 	NemoView *new_content_view;
@@ -165,7 +161,6 @@ void    nemo_window_slot_go_home			   (NemoWindowSlot *slot,
 							    NemoWindowOpenFlags flags);
 void    nemo_window_slot_go_up                         (NemoWindowSlot *slot,
 							    NemoWindowOpenFlags flags);
-
 void    nemo_window_slot_set_content_view_widget	   (NemoWindowSlot *slot,
 							    NemoView       *content_view);
 void    nemo_window_slot_set_viewed_file		   (NemoWindowSlot *slot,
